@@ -7,10 +7,8 @@ Created on Thu Jul 29 17:14:23 2021
 # %%
 import pandas as pd
 import numpy as np
-from copy import copy
 import matplotlib.pyplot as plt
 from .private_func import _preprocessing
-from .private_func import _get_report
 from .private_func import _corr2
 
 
@@ -249,7 +247,7 @@ class simpletest():
             ax_.legend(loc='lower right')
         ax_.set_ylabel('Value')
 
-        ax.text(x_line[peak_idx], cdf_line[peak_idx], 'factor val: {:.2f}'.format(peak))
+        ax.text(x_line[peak_idx], cdf_line[peak_idx], 'factor val: {:.3f}'.format(peak))
 
         return dict(ax=ax, ax_twinx=ax_)
 
@@ -367,6 +365,8 @@ class simpletest():
 
         if title is not None:
             plt.title(str(title))
+            _ = plt.xticks([])
+            _ = plt.yticks([])
 
         Y = pd.concat([y.rolling(i).sum().shift(-i + 1).rename(str(i)) \
                        for i in range(1, markout_periods + 1)], axis=1)
